import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class ASofterWorld(BasicComicModule):
    latestUrl = 'http://www.asofterworld.com/today.htm'
    imageUrl = 'http://www.asofterworld.com/soft_%s.htm'
    imageSearch = re.compile(r'latest comic.*?[^>].+<IMG SRC="(.*?)"')
    prevSearch = re.compile(r'"(.*?)">.*?back')
    help = 'Index format: mmmd_yyyy'
